#[non_exhaustive]pub enum Launchable {
DesktopId(String),
Service(String),
Url(Url),
CockpitManifest(String),
}Expand description
Indicates possible methods to launch the application. See <launchable/>.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DesktopId(String)
The application can be launched via a desktop file. See Desktop File ID.
Service(String)
The software can be started, stopped and monitored by the OS “init” such as systemd.
Url(Url)
The application is a website viewed through a browser.
CockpitManifest(String)
The software can be launched from the menus of the Cockpit admin interface.