Struct
AppStreamComposeIconPolicyIter
Description [src]
struct AscIconPolicyIter {
/* No available fields */
}
A AscIconPolicyIter structure represents an iterator that can be used
to iterate over the icon sizes / policy entries of an AscIconPolicy.
AscIconPolicyIter structures are typically allocated on the stack and
then initialized with asc_icon_policy_iter_init().
Instance methods
asc_icon_policy_iter_init
Initializes a policy iterator for the policy entry list and associates it
it with ipolicy.
The AscIconPolicyIter structure is typically allocated on the stack
and does not need to be freed explicitly.